@@ -8,7 +8,7 @@ qqsum <- function (x, y){
     sx <- approx(1:lenx, sx, n = leny)$y
   if (leny > lenx) 
     sy <- approx(1:leny, sy, n = lenx)$y
-  dxy <- sqrt(2)*abs(sx-sy)
+  dxy <- abs(sx-sy)
   meandiff <- mean(dxy)
   meddiff <- as.numeric(median(dxy))
   maxdiff <- max(dxy)
